==> kie-wb-common-7.25.0.Final-project-sources.tar.gz: kie-wb-common-7.25.0.Final/kie-wb-common-stunner/kie-wb-common-stunner-sets/kie-wb-common-stunner-case-mgmt/kie-wb-common-stunner-case-mgmt-client/src/main/java/org/kie/workbench/common/stunner/cm/client/forms/filters/ProcessReusableSubProcessFilterProvider.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.stunner.cm.client.forms.filters;

import javax.enterprise.event.Event;
import javax.inject.Inject;

import org.kie.workbench.common.stunner.bpmn.client.forms.filters.MultipleInstanceNodeFilterProvider;
import org.kie.workbench.common.stunner.cm.definition.ProcessReusableSubprocess;
import org.kie.workbench.common.stunner.core.client.api.SessionManager;
import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;

public class ProcessReusableSubProcessFilterProvider extends MultipleInstanceNodeFilterProvider {

    public ProcessReusableSubProcessFilterProvider() {
        this(null, null);
    }

    @Inject
    public ProcessReusableSubProcessFilterProvider(final SessionManager sessionManager,
                                                   final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent) {
        super(sessionManager, refreshFormPropertiesEvent);
    }

    @Override
    public boolean isMultipleInstance(Object definition) {
        final ProcessReusableSubprocess subProcess = (ProcessReusableSubprocess) definition;
        return subProcess.getExecutionSet().getIsMultipleInstance().getValue();
    }

    @Override
    public Class<?> getDefinitionType() {
        return ProcessReusableSubprocess.class;
    }
}

==> kie-wb-common-7.31.0.Final-project-sources.tar.gz: kie-wb-common-7.31.0.Final/kie-wb-common-stunner/kie-wb-common-stunner-sets/kie-wb-common-stunner-case-mgmt/kie-wb-common-stunner-case-mgmt-client/src/main/java/org/kie/workbench/common/stunner/cm/client/forms/filters/ProcessReusableSubProcessFilterProvider.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.stunner.cm.client.forms.filters;

import javax.enterprise.event.Event;
import javax.inject.Inject;

import org.kie.workbench.common.stunner.bpmn.client.forms.filters.BaseReusableSubProcessFilterProvider;
import org.kie.workbench.common.stunner.cm.definition.ProcessReusableSubprocess;
import org.kie.workbench.common.stunner.core.client.api.SessionManager;
import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;

public class ProcessReusableSubProcessFilterProvider extends BaseReusableSubProcessFilterProvider<ProcessReusableSubprocess> {

    @Inject
    public ProcessReusableSubProcessFilterProvider(final SessionManager sessionManager,
                                                   final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent) {
        super(sessionManager, refreshFormPropertiesEvent, ProcessReusableSubprocess.class);
    }
}
